@@ -194,6 +194,7 @@ class build_config:
         self.asmflag = ''
         self.ldflag = ''
         self.define = []
+        self.linktype = ''
 
         for k, v in dic.items():
             if v:
@@ -201,7 +202,7 @@ class build_config:
 
     def out(self):
         text = ''
-        for k in ['cflag', 'cxxflag', 'asmflag', 'ldflag']:
+        for k in ['cflag', 'cxxflag', 'asmflag', 'ldflag', 'linktype']:
             value = self.__dict__[k]
             if value:
                 if len(value) < 60:
