@@ -25,7 +25,7 @@ Format component package.yaml file
         count = len(args)
         for name in args:
             if name not in name_list:
-                put_string("There is no component:%s found." % name)
+                put_string("There is no component:%s found." % name, level='warning')
         for component in yoc.components:
             if count == 0 or component.name in args:
                 put_string("Formating package: %s." % component.name)
