@@ -21,7 +21,7 @@ toolchain_url_32 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-to
 rsicv_url_64 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-x86_64.tar.gz'
 rsicv_url_32 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-i386.tar.gz'
 
-arm_url_64 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/gcc-arm-none-eabi-9-2020-q2-update-x86_64-linux.tar.gz'
+arm_url_64 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/gcc-arm-none-eabi-x86_64-linux.tar.gz'
 arm_url_32 = ''
 
 all_toolchain_url = {
